@@ -7,9 +7,7 @@ use namespace::autoclean;
 extends 'Data::Collector::Info';
 with    'Data::Collector::Commands';
 
-sub load {
-    Data::Collector::Info->register( qw/ total_memory free_memory / );
-}
+sub info_keys { [qw/total_memory free_memory/] }
 
 sub _build_raw_data {
     my $self = shift;
@@ -54,10 +52,10 @@ I<total_memory>.
 
 =head1 SUBROUTINES/METHODS
 
-=head2 load
+=head2 info_keys
 
-Subclassing C<load> from L<Data::Collector::Info> to register keys in the
-registry.
+Subclassing C<info_keys> from L<Data::Collector::Info> to indicate which keys
+to register.
 
 =head2 total
 
